@@ -4,7 +4,7 @@ import schemathesis
 # before moved to data folder
 # schema = schemathesis.from_path('./test_openapi_paths/pet3.json')
 
-schema = schemathesis.from_path('./data/pet3.json')
+schema = schemathesis.from_path('../data/pet3.json')
 schema.base_url = "https://petstore3.swagger.io/api/v3/"
 
 
